# Device-Drama - Linux Fetch Tool

Simple fetch tool for Linux devices

Please check [Wiki](https://github.com/8tm/device-drama/wiki/Home) to know:
- [How to](https://github.com/8tm/device-drama/wiki/installation) (un)install this tool
- [How to](https://github.com/8tm/device-drama/wiki/requirements) (un)install external requirements
- [How to](https://github.com/8tm/device-drama/wiki/personalization) personalize Device-Drama
- [How to](https://github.com/8tm/device-drama/wiki/plugins) create your own plugins
